==> pyllmut-0.3.0.tar.gz: pyllmut-0.3.0/README.md <==
# PyLLMut

[![PyPI version](https://badge.fury.io/py/pyllmut.svg)](https://badge.fury.io/py/pyllmut)
[![PyPI Downloads](https://static.pepy.tech/badge/pyllmut)](https://pepy.tech/projects/pyllmut)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](LICENSE.txt)
[![Docs](https://readthedocs.org/projects/pyllmut/badge/?version=latest)](https://pyllmut.readthedocs.io/en/latest/)
![Status](https://img.shields.io/badge/Status-Experimental-orange)
![Research](https://img.shields.io/badge/Research-Driven-lightgrey)
![Open Source](https://img.shields.io/badge/Open%20Source-Yes-brightgreen)
[![Tests](https://github.com/mohrez86/pyllmut/actions/workflows/test-all.yml/badge.svg)](https://github.com/mohrez86/pyllmut/actions/workflows/test-all.yml)

## Introduction

PyLLMut—pronounced "Pill Moot" (/pɪl muːt/)—is 
a research-based LLM-driven mutant generator library 
for Python. It uses Large Language Models (LLMs) to 
generate mutants for a given Python module.
The current version of PyLLMut 
supports `gpt-4o-mini` through its API. 
We plan to add support for more models, 
such as *DeepSeek-R1*.

## Documentation  

Full documentation is available at
[PyLLMut Documentation](https://pyllmut.readthedocs.io).  

## Installation  

To install PyLLMut, follow the instructions in the 
[Installation Guide](https://pyllmut.readthedocs.io/en/latest/user/install).  

## Usage  

For a quick example of how to use PyLLMut, refer to the 
[Quick Start Guide](https://pyllmut.readthedocs.io/en/latest/user/start).  

## API Reference  

For details on PyLLMut's available API, refer to the 
[API Reference](https://pyllmut.readthedocs.io/en/latest/api/generator).  

## Acknowledgments  

PyLLMut is a research-based project, inspired by the study 
[On the Use of Large Language Models in 
Mutation Testing](https://arxiv.org/abs/2406.09843), which was 
originally for Java.

==> pyllmut-0.4.0.tar.gz: pyllmut-0.4.0/README.md <==
# PyLLMut

[![PyPI version](https://badge.fury.io/py/pyllmut.svg)](https://badge.fury.io/py/pyllmut)
[![PyPI Downloads](https://static.pepy.tech/badge/pyllmut)](https://pepy.tech/projects/pyllmut)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](LICENSE.txt)
[![Docs](https://readthedocs.org/projects/pyllmut/badge/?version=latest)](https://pyllmut.readthedocs.io/en/latest/)
![Status](https://img.shields.io/badge/Status-Experimental-orange)
![Research](https://img.shields.io/badge/Research-Driven-lightgrey)
![Open Source](https://img.shields.io/badge/Open%20Source-Yes-brightgreen)
[![Tests](https://github.com/mohrez86/pyllmut/actions/workflows/test-all.yml/badge.svg)](https://github.com/mohrez86/pyllmut/actions/workflows/test-all.yml)

## Introduction

PyLLMut—pronounced "Pill Moot" (/pɪl muːt/)—is 
a research-based LLM-driven mutant generator library 
for Python. It uses Large Language Models (LLMs) to 
generate mutants for Python programs.
The current version of PyLLMut 
supports `GPT-4o` and `GPT-4o mini` through their APIs. 
We plan to add support for more models, 
such as *DeepSeek-R1*.

## Documentation  

Full documentation is available at
[PyLLMut Documentation](https://pyllmut.readthedocs.io).  

## Installation  

To install PyLLMut, follow the instructions in the 
[Installation Guide](https://pyllmut.readthedocs.io/en/latest/user/install).  

## Usage  

For a quick example of how to use PyLLMut, refer to the 
[Quick Start Guide](https://pyllmut.readthedocs.io/en/latest/user/start).  

## API Reference  

For details on PyLLMut's available API, refer to the 
[API Reference](https://pyllmut.readthedocs.io/en/latest/api/generator).  

## Acknowledgments  

PyLLMut is a research-based project, inspired by the study 
[On the Use of Large Language Models in 
Mutation Testing](https://arxiv.org/abs/2406.09843), which was 
originally for Java.
